@@ -48,7 +48,7 @@ def ts_outlier_plot(data, dt, y):
 
 def separability_plot(df, trgt):
     df=df.copy()
-    df=df.select_dtypes(include='numeric')
+    df=df.select_dtypes(include='number')
 
     fig,ax=plt.subplots(1,3,figsize=(15,5))
     cls = df.pop(trgt)
